@@ -1,8 +1,9 @@
-from .cache import Cache
+from .cache import Cache, LRUCache
 from .deco import acached, cached
 
 __all__ = (
     "Cache",
+    "LRUCache",
     "acached",
     "cached",
 )
